@@ -23,7 +23,7 @@ from aliyunsdkvod.endpoint import endpoint_data
 class GetVideoInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'vod', '2017-03-21', 'GetVideoInfo','vod')
+		RpcRequest.__init__(self, 'vod', '2017-03-21', 'GetVideoInfo')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -31,32 +31,8 @@ class GetVideoInfoRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_ResourceOwnerId(self):
-		return self.get_query_params().get('ResourceOwnerId')
-
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ResourceOwnerAccount(self):
-		return self.get_query_params().get('ResourceOwnerAccount')
-
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
 	def get_VideoId(self):
 		return self.get_query_params().get('VideoId')
 
 	def set_VideoId(self,VideoId):
-		self.add_query_param('VideoId',VideoId)
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_AdditionType(self):
-		return self.get_query_params().get('AdditionType')
-
-	def set_AdditionType(self,AdditionType):
-		self.add_query_param('AdditionType',AdditionType)
\ No newline at end of file
+		self.add_query_param('VideoId',VideoId)
\ No newline at end of file
